#!/usr/bin/perl -w
#
# a1.pl
# Definition of remote site server

use lib '/usr/local/lib/raddle/branch-network';

use strict;

use Net::Raddle::SNMPAgent qw( IPToMAC Netmask CanonicalOID);
use Net::Raddle::TrafficGen;
use netconfig;
# We need the type definitions when adding individual values
use NetSNMP::ASN (':all');

# net-snmp cannot give us command-line parameters so we use an environment variable
# to set the debug level
#
my $debug = $ENV{RADDLE_DEBUG};
$debug = 0 if not $debug;
print "DEBUG: $debug\n" if $debug;

# Set up the emulator
my $agent = Net::Raddle::SNMPAgent->new( debugging => $debug )
	 or die "Could not initialise Net::Raddle::SNMPAgent";

# Load the boilerplate
# Use the installed version if present, otherwise look in current directory
$agent->ParseDataFile( '/usr/local/lib/raddle/branch-network/a1.snmp' )
	or $agent->ParseDataFile( 'a1.snmp' )
	or die( "Cannot read the a1.snmp boilerplate file" );

# Override name and location
$agent->SetMIBValue( CanonicalOID('SNMPv2-MIB::sysName.0'), ASN_OCTET_STR,
                        "group-$GroupNumber-a1.class.example.org");
$agent->SetMIBValue( CanonicalOID('SNMPv2-MIB::sysLocation.0'), ASN_OCTET_STR,
                        "Virtual machine room $GroupNumber");

# Date and time of boot - about a week before the actual start-time
$agent->TieMIBItem( CanonicalOID('SNMPv2-MIB::sysUpTime.0'), ASN_TIMETICKS, "Net::Raddle::TicksSince",
                (time - 7*24*3600 - 17263));


# Add Loopback interface
#
# First set up some traffic generators
my $LoopPkts = Net::Raddle::TrafficGen->new({rate => 100});
my $LoopBytes = Net::Raddle::TrafficGen->new({rate => 100*250});
#
my $LoopbackIndex = $agent->AddIF( {
			ifDescr => 'Loopback0',
			ifType => 24,
			ifSpeed => 4294967295,
                        ifInOctets => $LoopBytes,
                        ifInUcastPkts => $LoopPkts,
                        ifOutOctets => $LoopBytes,
                        ifOutUcastPkts => $LoopPkts,
	} );

# Bind IP address to Loopback
$agent->AddIpAddrEntry( {
			ipAdEntAddr => '127.0.0.1',
			ipAdEntIfIndex => $LoopbackIndex,
			ipAdEntNetMask => '255.0.0.0',
              } );


# Add Fast Ether
# This is a server of some sort so we simulate fairly high traffic
#
my $ifSpeed = 100000000;
#
my $fe0Index = $agent->AddIF( {
			ifDescr => 'eth0',
			ifType => 6,
			ifPhysAddress => IPToMAC('08:00', $HostA1Addr),
			ifSpeed => $ifSpeed,
			# Inbound mean 12% load, 220-byte packets
			ifInOctets => Net::Raddle::TrafficGen->new({
					rate => $ifSpeed * 0.12 / 8,
					limit => $ifSpeed, }),
			ifInUcastPkts => Net::Raddle::TrafficGen->new({
					rate => $ifSpeed * 0.12 / (8*220), }),
			# Outbound mean 80% load, 1400-byte packets
			ifOutOctets => Net::Raddle::TrafficGen->new({
					rate => $ifSpeed * 0.7 / 8,
					limit => $ifSpeed, }),
			ifOutUcastPkts => Net::Raddle::TrafficGen->new({
					rate => $ifSpeed * 0.8 / (8*1400), }),
			ifInUnknownProtos => int rand 120,
	} );

# Bind IP address to Fast Ether
$agent->AddIpAddrEntry( {
			ipAdEntAddr => $HostA1Addr,
			ipAdEntIfIndex => $fe0Index,
			ipAdEntNetMask => Netmask( $NetAMaskLen ),
              } );


# Now some routing table entries
#jc - change route types
$agent->AddIpRouteEntry ({
         ipRouteDest => '0.0.0.0',
         ipRouteIfIndex => $fe0Index,
         ipRouteNextHop => $R2NetAAddr,
         ipRouteType => 3,		# Indirect
         ipRouteProto => 2,
         ipRouteMask => '0.0.0.0',
});

$agent->AddIpRouteEntry ({
         ipRouteDest => "$NetANet",
         ipRouteIfIndex => $fe0Index,
         ipRouteNextHop => "$HostA1Addr",
         ipRouteType => 3,
         ipRouteProto => 2,
         ipRouteMask => Netmask( $NetAMaskLen ) ,
});

