#!/usr/bin/perl -w
#
# netconfig.pm
#
# Defines config variables for emulation

package netconfig;

# The name of the file that we scan to find config data
# If ConfigFile1 exists then it takes precedence.

my $ConfigFile1 = '/usr/local/etc/branch-network-config';
my $ConfigFile2 = '/usr/local/lib/raddle/branch-network/network-config';

require Exporter;
@ISA = qw(Exporter);
@EXPORT = qw(
	$GroupNumber

	$ClassNetNet
	$ClassNetDefaultRoute
	$ClassNetMaskLen

	$SerialNetPrefix
	$SerialNetNet
	$SerialNetMaskLen
	$NetANet
	$NetAMaskLen
	$NetBNet
	$NetBMaskLen
	$NetCNet
	$NetCMaskLen
	$SiteNetPrefix
	$SiteSuperNet
	$SiteSuperNetMaskLen

	$R1ClassNetAddr
	$R1SerialNetAddr
	$R1DefaultRoute
	$R1ClassNetMAC

	$R2SerialNetAddr
	$R2NetAAddr
	$R2NetBAddr
	$R2DefaultRoute

	$R3NetAAddr
	$R3NetBAddr
	$R3NetCAddr
	$R3DefaultRoute

	$HostA1Addr
	$HostB1Addr
	$HostB2Addr
	$HostC1Addr
	$HostC2Addr
	$HostC3Addr

	$SwitchS1Addr
	$SwitchS1BaseMAC
	$SwitchS2Addr
	$SwitchS2BaseMAC

);


# Things that need to change depending on classroom environment
#
# e.g.:
# $ClassNetDefaultRoute = "10.0.0.2";
# $R1ClassNetAddr = "10.0.0.176";
# $ClassNetNet = "10.0.0.0";
# $ClassNetMaskLen = 16;
# 
# The number of this work group is used as part of many addresses
# $GroupNumber = 6;

$ClassNetDefaultRoute = undef;
$R1ClassNetAddr = undef;
$ClassNetNet = undef;
$ClassNetMaskLen = undef;
$GroupNumber = undef;

# These should only change if they clash with the class net
$SerialNetPrefix = '172.30';
$SerialNetMaskLen = 30;
$SiteNetPrefix = '172.31';
$SiteSuperNetMaskLen = 24;
$NetAMaskLen = 28;
$NetBMaskLen = 28;
$NetCMaskLen = 28;

# Parse config file
open CONFIG, "<$ConfigFile1"
	or open CONFIG, "<$ConfigFile2"
	or die "Cannot read $ConfigFile1 or $ConfigFile2\n";
while (<CONFIG>) {
	chomp;
	# Remove comments and blank lines
	s/#.*$//;
	next if (/^\s*$/);

	my ($var, $data) = /^([a-zA-Z0-9_-]+)\s+(.*)$/;
	# print "GOT CONFIG: '$var' '$data'\n";

	$GroupNumber = $data if ($var eq 'GROUP_NUMBER');
	$R1ClassNetAddr = $data if ($var eq 'R1_ADDR');
	$ClassNetNet = $data if ($var eq 'R1_NETWORK');
	$ClassNetMaskLen = $data if ($var eq 'R1_MASK_LENGTH');
	$ClassNetDefaultRoute = $data if ($var eq 'R1_DEFAULT_ROUTE');

	$SerialNetPrefix = $data if ($var eq 'SerialNetPrefix');
	$SerialNetMaskLen =  $data if ($var eq 'SerialNetMaskLen');
	$SiteNetPrefix = $data if ($var eq 'SiteNetPrefix');
	$SiteSuperNetMaskLen = $data if ($var eq 'SiteSuperNetMaskLen');
	$NetAMaskLen = $data if ($var eq 'NetAMaskLen');
	$NetBMaskLen = $data if ($var eq 'NetBMaskLen');
	$NetCMaskLen = $data if ($var eq 'NetCMaskLen');
}
close CONFIG;

# Network numbers
$SerialNetNet = "$SerialNetPrefix.$GroupNumber.0";
$NetANet = "$SiteNetPrefix.$GroupNumber.0";
$NetBNet = "$SiteNetPrefix.$GroupNumber.16";
$NetCNet = "$SiteNetPrefix.$GroupNumber.32";
$SiteSuperNet = "$SiteNetPrefix.$GroupNumber.0";


# R1 - the main site router
$R1SerialNetAddr = "$SerialNetPrefix.$GroupNumber.1";
$R1DefaultRoute = $ClassNetDefaultRoute;

open IFCONFIG, "/sbin/ifconfig eth0|" or die "Cannot run ifconfig\n";
while (<IFCONFIG>) {
	next if (! /HWaddr/ );

	($R1ClassNetMAC) = /HWaddr\s+([0-9a-zA-Z:]+)/;
}
close IFCONFIG;
# print "MAC addr $R1ClassNetMAC\n";

# R2 - the remote site access router
$R2SerialNetAddr = "$SerialNetPrefix.$GroupNumber.2";
$R2NetAAddr = "$SiteNetPrefix.$GroupNumber.1";
$R2NetBAddr = "$SiteNetPrefix.$GroupNumber.17";
$R2DefaultRoute = $R1SerialNetAddr;

# R3 - the remote site internal router
$R3NetAAddr = "$SiteNetPrefix.$GroupNumber.2";
$R3NetBAddr = "$SiteNetPrefix.$GroupNumber.18";
$R3NetCAddr = "$SiteNetPrefix.$GroupNumber.33";
$R3DefaultRoute = $R2NetAAddr;

# Site hosts
$HostA1Addr = "$SiteNetPrefix.$GroupNumber.3";
$HostB1Addr = "$SiteNetPrefix.$GroupNumber.19";
$HostB2Addr = "$SiteNetPrefix.$GroupNumber.20";
$HostC1Addr = "$SiteNetPrefix.$GroupNumber.34";
$HostC2Addr = "$SiteNetPrefix.$GroupNumber.35";
$HostC3Addr = "$SiteNetPrefix.$GroupNumber.36";

# Switches
$SwitchS1Addr = "$SiteNetPrefix.$GroupNumber.37";
$SwitchS1BaseMAC = "00:04:C1:01:00:C0";
$SwitchS2Addr = "$SiteNetPrefix.$GroupNumber.21";
$SwitchS2BaseMAC = "00:04:C1:02:00:C0";

########################################################################
# This is a module so return true
########################################################################
1;
########################################################################
